#!/usr/bin/env Python
# _*_coding:utf-8 _*_

"""
Mysql:
input: config
eg:
CONFIG = read_config()
config = CONFIG['local']

get_data_one(config, sql)
get_data_all(config, sql)
insert_or_update_data(config, sql)
insert_data_list(config, sql)
"""

"""
Yaml:
eg: 
my_yaml=DoYaml(filename)
res=my_yaml.read_config()
"""
